@@ -36,7 +36,7 @@ def job(ctx, job_id):
             job_id = int(job_id)
         except ValueError:
             abort("job_id should be a number or 'latest', not '%s'" % job_id)
-    job_resource = find_job(ctx.obj.session, job_id)
+    job_resource = find_job(ctx.obj.service, job_id)
     if not job_resource:
         abort("Job not found")
 
