@@ -695,7 +695,10 @@ def link(ctx, link_type):
             "&_a=(columns:!(kubernetes.labels.taskName,message),interval:auto,"
             "query:(language:lucene,query:'kubernetes.labels.job-id:{job_id}%20%26%26%20kubernetes.labels.started-by:workflow-service'),"
             "sort:!('@timestamp',desc))".format(
-                kibana_url=kibana_url, start_date=start_date, end_date=end_date, job_id=job_id,
+                kibana_url=kibana_url,
+                start_date=start_date,
+                end_date=end_date,
+                job_id=job_id,
             )
         )
         echo(link)
